@@ -71,8 +71,8 @@ print <<END;
 If your terminal supports
 this many colors:                  8    16   256
 
-Then you'll see approximately
-this many shades of color above:
+Then you'll see about this many
+distinct shades of color above:
 System colors ..................   8    16   8-16
 Color squares (each) ...........   3    10    36
 Greyscale ramp (incl. black) ...   1     4    25
